AFRL labeling Sub Collection Info (sarpy.annotation.afrl_elements.SubCollectionInfo)
====================================================================================

.. automodule:: sarpy.annotation.afrl_elements.SubCollectionInfo
    :members:
    :show-inheritance:
    :inherited-members:
